import sys
import typing


class AssetBrowserPanel:
    bl_space_type = None
    ''' '''

    def asset_browser_panel_poll(self, context):
        ''' 

        '''
        pass

    def poll(self, context):
        ''' 

        '''
        pass


class AssetMetaDataPanel:
    bl_region_type = None
    ''' '''

    bl_space_type = None
    ''' '''

    def poll(self, context):
        ''' 

        '''
        pass


class SpaceAssetInfo:
    pass
